@@ -56,6 +56,7 @@ import org.osgi.framework.BundleContext;
 import org.osgi.framework.Filter;
 import org.osgi.framework.InvalidSyntaxException;
 import org.osgi.util.tracker.ServiceTracker;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.context.ContextService;
 import com.openexchange.kerberos.KerberosService;
 import com.openexchange.osgi.Tools;
@@ -76,7 +77,7 @@ public class AuthenticationActivator implements BundleActivator {
 
     @Override
     public void start(BundleContext context) throws InvalidSyntaxException {
-        Filter filter = generateServiceFilter(context, KerberosService.class, ContextService.class, UserService.class);
+        Filter filter = generateServiceFilter(context, KerberosService.class, ContextService.class, UserService.class, ConfigurationService.class);
         trackers.push(new ServiceTracker<Object, Object>(context, filter, new AuthenticationRegisterer(context)));
 //        filter = generateServiceFilter(context, TimerService.class, KerberosService.class);
 //        trackers.push(new ServiceTracker(context, filter, new RenewalLoginHandlerRegisterer(context)));
